Struct clmm_common::contract::state::farming::mint_wrapper::Minter
source · [−]pub struct Minter {
pub mint_wrapper: Pubkey,
pub minter_authority: Pubkey,
pub bump: u8,
pub index: u64,
pub allowance: u64,
pub total_minted: u64,
}Fields
mint_wrapper: PubkeyThe mint wrapper.
Address that can mint.
bump: u8Bump seed.
index: u64Auto-incrementing index of the Minter.
allowance: u64Limit of number of tokens that this Minter can mint.
total_minted: u64Cumulative sum of the number of tokens ever minted by this Minter.
Implementations